==> unity_4.10.0.orig.tar.bz2: unity-4.10.0/plugins/unityshell/src/ResultRendererHorizontalTile.h <==
/*
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3, as
 * published by the  Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the applicable version of the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of both the GNU Lesser General Public
 * License version 3 along with this program.  If not, see
 * <http://www.gnu.org/licenses/>
 *
 * Authored by: Gordon Allott <gord.allott@canonical.com>
 *
 */



#ifndef RESULTRENDERERHORIZONTALTILE_H
#define RESULTRENDERERHORIZONTALTILE_H

#include <Nux/Nux.h>
#include <NuxCore/Object.h>
#include <NuxCore/Property.h>
#include "Nux/TextureArea.h"
#include "NuxImage/CairoGraphics.h"

#include "ResultRenderer.h"

namespace unity
{
namespace dash
{

// Initially unowned object
class ResultRendererHorizontalTile : public ResultRenderer
{
public:
  ResultRendererHorizontalTile(NUX_FILE_LINE_PROTO);
  virtual ~ResultRendererHorizontalTile();

  inline virtual void Render(nux::GraphicsEngine& GfxContext, Result& row, ResultRendererState state, nux::Geometry& geometry, int x_offset, int y_offset);
  virtual void Preload(Result& row);  // this is just to start preloading images and text that the renderer might need - can be ignored
  virtual void Unload(Result& row);  // unload any previous grabbed images

private:
  void LoadText(std::string& text);
  void LoadIcon(std::string& icon_hint);

  //icon loading callbacks
  void IconLoaded(const char* texid, guint size, GdkPixbuf* pixbuf, std::string icon_name);
  void CreateTextureCallback(const char* texid, int width, int height, nux::BaseTexture** texture, GdkPixbuf* pixbuf);
  void CreateBlurredTextureCallback(const char* texid, int width, int height, nux::BaseTexture** texture, GdkPixbuf* pixbuf);
  void DrawHighlight(const char* texid, int width, int height, nux::BaseTexture** texture);

  typedef std::map<std::string, nux::BaseTexture*> LocalTextureCache;

  LocalTextureCache icon_cache_;
  LocalTextureCache blurred_icon_cache_;
  LocalTextureCache text_cache_;
  nux::BaseTexture* prelight_cache_;
  std::map<std::string, uint> currently_loading_icons_;

};

}
}
#endif // RESULTRENDERERHORIZONTALTILE_H

==> unity_4.14.2.orig.tar.bz2: unity-4.14.2/plugins/unityshell/src/ResultRendererHorizontalTile.h <==
// -*- Mode: C++; indent-tabs-mode: nil; tab-width: 2 -*-
/*
 * Copyright 2011 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3, as
 * published by the  Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the applicable version of the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of both the GNU Lesser General Public
 * License version 3 along with this program.  If not, see
 * <http://www.gnu.org/licenses/>
 *
 * Authored by: Gordon Allott <gord.allott@canonical.com>
 *
 */



#ifndef RESULTRENDERERHORIZONTALTILE_H
#define RESULTRENDERERHORIZONTALTILE_H

#include <Nux/Nux.h>
#include <NuxCore/Object.h>
#include <NuxCore/Property.h>
#include <Nux/TextureArea.h>
#include <NuxImage/CairoGraphics.h>

#include "ResultRendererTile.h"

namespace unity
{
namespace dash
{

// Initially unowned object
class ResultRendererHorizontalTile : public ResultRendererTile
{
public:
  NUX_DECLARE_OBJECT_TYPE(ResultRendererHorizontalTile, ResultRendererTile);

  ResultRendererHorizontalTile(NUX_FILE_LINE_PROTO);
  ~ResultRendererHorizontalTile();

  virtual void Render(nux::GraphicsEngine& GfxContext,
                      Result& row,
                      ResultRendererState state,
                      nux::Geometry& geometry,
                      int x_offset, int y_offset);

protected:
  void LoadText(Result& row);

private:
  nux::BaseTexture* DrawHighlight(std::string const& texid,
                                  int width, int height);
};

}
}
#endif // RESULTRENDERERHORIZONTALTILE_H
